#
# spec file for package yum
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yum
Version:        3.4.3
Release:        16.1
Summary:        RPM installer/updater
License:        GPL-2.0+
Group:          System/Packages
Url:            http://linux.duke.edu/yum/
Source:         %{name}-%{version}.tar.gz
Source1:        %{name}.conf
Source2:        %{name}-updatesd.init
# PATCH-FIX-OPENSUSE
Patch1:         %{name}-3.4.3-license-to-confirm.patch
# PATCH-FIX-OPENSUSE
Patch2:         %{name}-3.4.3-suse-changelogs.patch
# PATCH-FIX-OPENSUSE
Patch3:         %{name}-3.4.3-suse-missing-tags.patch
# PATCH-FIX-OPENSUSE
Patch6:         %{name}-3.4.3-add-lib-cpp-file.patch
# PATCH-FIX-UPSTREAM
Patch7:         %{name}-3.4.3-updatesd-dbus-conf-syntax.patch
# PATCH-FIX-UPSTREAM
Patch8:         %{name}-3.4.3-speedup-bnc810074.patch
# PATCH-FIX-OPENSUSE
Patch9:         %{name}-3.4.3-fix-repo-tag.patch
# PATCH-FIX-UPSTREAM bnc#896844
Patch10:        %{name}-3.4.3-preserve-queryparams-in-urls.patch
BuildRequires:  dbus-1
BuildRequires:  intltool
BuildRequires:  python-devel
Requires:       python-gpgme
Requires:       python-iniparse
Requires:       python-xml
Requires:       python-yum = %{version}
Requires:       rpm >= 4.4.0
Requires:       rpm-python
Suggests:       cron
Suggests:       logrotate
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  coreutils
Requires(pre):  %insserv_prereq
Requires(pre):  %fillup_prereq
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%lang_package
%description
Yum is a utility that can check for and automatically download and
install updated RPM packages. Dependencies are obtained and downloaded
automatically prompting the user as necessary.

%package updatesd
Summary:        YUM update notification daemon
Group:          System/Packages
Requires:       %{name} = %{version}
Requires:       dbus-1-python
Requires:       python-gobject2
Requires(pre):  %insserv_prereq

%description updatesd
yum-updatesd provides a daemon which checks for available updates and
can notify you when they are available via email, syslog or dbus.

%package -n python-yum
Summary:        YUM update notification daemon
Group:          Development/Languages/Python
Requires:       dbus-1-python
Requires:       python-gobject2
Requires:       python-urlgrabber
Requires:       python-urlgrabber
Requires:       yum-metadata-parser >= 1.1.0
Provides:       yum-common = %{version}
Obsoletes:      yum-common < %{version}

%description -n python-yum
Common libraries for YUM based programs

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

# Fix non-executable scripts rpmlint issue:
sed -i "s|#!.*/usr/bin/python.*||" rpmUtils/{arch,__init__,miscutils,oldUtils,transaction,updates}.py
sed -i "s|#!.*/usr/bin/python.*||" yum/{callbacks,comps,config,constants,depsolve,Errors,failover,history,i18n,__init__,logginglevels,mdparser,metalink,misc,packages,packageSack,parser,pgpmsg,pkgtag_db,plugins,repoMDObject,repos,rpmsack,rpmtrans,sqlitesack,sqlutils,transactioninfo,update_md,yumRepo}.py

%ifnarch %{ix86}
for i in rpmUtils yum
do
  pushd $i
  sed -e "s/lib/%{_lib}/" Makefile > Makefile.new
  mv Makefile.new Makefile
  popd
done
%endif

%build
make

%install
%makeinstall
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}/yum.conf

# install custom init script
mkdir -p %{buildroot}%{_sysconfdir}/init.d
install %{SOURCE2} %{buildroot}%{_initddir}/yum-updatesd
ln -s %{_initddir}/yum-updatesd %{buildroot}%{_sbindir}/rcyum-updatesd
# remove the original one
rm %{buildroot}%{_sysconfdir}/rc.d/init.d/yum-updatesd
rm -rf %{buildroot}%{_sysconfdir}/rc.d

mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/pluginconf.d/ \
         %{buildroot}%{_prefix}/lib/yum-plugins/ \
         %{buildroot}%{_localstatedir}/adm/fillup-templates/
mv %{buildroot}%{_sysconfdir}/sysconfig/yum-cron %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.yum-cron
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
rm -rf %{buildroot}%{_prefix}/share/locale/id_ID
rm -rf %{buildroot}%{_prefix}/share/locale/lt_LT
%endif
%find_lang %{name}

%post
%fillup_only -n yum-cron
# if we are upgrading from older distros the config should be moved
# to the new place
CONFD="/etc/yum"
OCONF="/etc/yum.conf"
NCONF="${CONFD}/yum.conf"
NCONFB="${CONFD}/yum.conf.rpmsave"
if [ -e "$OCONF" ] ; then
#
# in worst case we will get:
# /etc/yum/yum.conf         - the old /etc/yum.conf
# /etc/yum/yum.conf.rpmnew  - the config of the newly installed package.
# /etc/yum/yum.conf.rpmsave - the old /etc/yum/yum.conf
#
    if [ ! -d "$CONFD" ] ; then
        mkdir "$CONFD"
    fi
#
# we dont need to handle the case that /etc/yum/yum.conf
# exists. rpm does that for us.
# it creates /etc/yum/yum.conf.rpmnew
#
    if [ -e "$NCONF" ] ; then
        mv "$NCONF" "$NCONFB"
        echo "warning: /etc/yum/yum.conf backed up as /etc/yum/yum.conf.rpmsave" >&2
    fi
    echo "warning: /etc/yum.conf moved to /etc/yum/yum.conf" >&2
    mv "$OCONF" "$NCONF"
fi
# migrate /etc/yum.repos.d to /etc/yum/repos.d/
if [ -d "/etc/yum.repos.d" ] ; then
    if [ ! -d "/etc/yum/repos.d" ] ; then
        mkdir "/etc/yum/repos.d"
    fi
    if [ "/etc/yum.repos.d/*" != '/etc/yum.repos.d/*' ] ; then
    for i in /etc/yum.repos.d/*;
    do
      NCONF="/etc/yum/repos.d/`basename $i`"
      NCONFB="/etc/yum/repos.d/`basename $i`.rpmsave"
      OCONF="/etc/yum.repos.d/`basename $i`"
      if [ -e "$NCONF" ] ; then
          mv "$NCONF" "$NCONFB"
          echo "warning: $NCONF backed up as $NCONFB" >&2
      fi
      echo "warning: $OCONF moved to $NCONF" >&2
      mv "$OCONF" "$NCONF"
    done
    fi
fi

%preun updatesd
%stop_on_removal yum-updatesd

%postun updatesd
%restart_on_update yum-updatesd
%insserv_cleanup

%files
%defattr(-,root,root)
%doc README AUTHORS COPYING TODO PLUGINS
%dir %{_localstatedir}/cache/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/repos.d
%dir %{_sysconfdir}/%{name}/pluginconf.d
%dir %{_prefix}/lib/yum-plugins
%config(noreplace) %{_sysconfdir}/%{name}/yum.conf
%config %{_sysconfdir}/logrotate.d/%{name}
%{_localstatedir}/adm/fillup-templates/sysconfig.yum-cron
%{_sysconfdir}/cron.daily/0yum.cron
%config %{_sysconfdir}/%{name}/yum-daily.yum
%config %{_sysconfdir}/%{name}/yum-weekly.yum
%config %{_sysconfdir}/bash_completion.d/yum.bash
%{_mandir}/*/*
%defattr(0755,root,root)
%{_datadir}/yum-cli
%{_bindir}/*
%exclude %{_mandir}/man*/yum-updatesd*

%files lang -f %name.lang
%defattr(-,root,root)

%files -n python-yum
%defattr(-,root,root)
%{python_sitearch}/*

%files updatesd
%defattr(-,root,root)
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/yum-updatesd.conf
%config %{_sysconfdir}/init.d/yum-updatesd
%{_sbindir}/rcyum-updatesd
%attr(644,root,root) %config %{_sysconfdir}/dbus-1/system.d/yum-updatesd.conf
%config(noreplace) %{_sysconfdir}/%{name}/version-groups.conf
%{_sbindir}/yum-updatesd
%{_mandir}/man*/yum-updatesd*

%changelog
* Tue Sep 16 2014 dmacvicar@suse.de
- Add 3.4.3-preserve-queryparams-in-urls.patch
  (bnc#896844)
* Mon Apr 14 2014 adrian@suse.de
- fix "repotag" support in modifyrepo
  new patch: yum-3.4.3-fix-repo-tag.patch
- include debian build descriptions, since we require this
  for travis-ci testing
* Thu Mar 13 2014 mls@suse.de
- simplify suse-missing-tags patch
* Mon Feb 24 2014 suse-tux@gmx.de
- minor change to the suse-missing-tags patch in order to fix bnc#841280
* Mon Feb 24 2014 mls@suse.de
- adapt suse-missing-tags tags to new rpm weak dependency tags
* Thu Jan  2 2014 info@michael-jansen.biz
- Move dependency to yum-metadata-parser to python-yum
* Tue Apr 16 2013 bwiedemann@suse.com
- fix SLE-11 build
* Mon Mar 25 2013 bwiedemann@suse.com
- speedup createrepo changelog code (bnc#810074)
  add yum-3.4.3-speedup-bnc810074.patch
  remove obsolete yum-3.4.3-disable-annoying-debuginfo.patch
* Thu Feb 23 2012 saschpe@suse.de
- Add yum-3.4.3-updatesd-dbus-conf-syntax.patch (sent upstream)
* Thu Feb 23 2012 saschpe@suse.de
- Update to version 3.4.3:
  * yum/__init__.py:  Don't call repo.doSetup() if we've already setup the
    repos.
  * yum/history.py, yum/rpmtrans.py:  Disable the rpmtrans chroot workaround.
    Use exclusive locking in history.
  * yummain.py: Change the logging for NFS path problems from debug to critical.
  * yummain.py: Checks if we have read and write access in the current
    directory. If not, chdir to /.
  * output.py: Make the source xgettext-friendly.  xgettext ignores
    _(var), so localize literals instead.
  * cli.py: Don't show -c warning, when we've changed it due to --installroot.
  * yum/rpmtrans.py:  Workaround rpm chroot insanity, so we can use sqlite from
    unInstStop() cb.
  - See changelog for more details...
- Rebased the following patches:
  * yum-3.2.25-license-to-confirm.patch
  * yum-3.2.25-suse-changelogs.patch
  * yum-3.2.25-suse-missing-tags.patch
  * yum-3.2.25-disable-annoying-debug-info.patch
  * yum-3.2.25-add-lib-cpp-file.patch
- Dropped the following patches:
  * yum-3.2.6-epoch_workaround.patch - Fixed upstream
  * yum-3.2.25-add-sourcerpm-for-old-yum.patch - Fixed upstream
- Spec file cleanup:
  * Ran spec-cleaner
  * Removed checks for SUSE versions older than 11.1
  * Provide rc-script for %%{_initdir}/yum-updatesd (Init script packaging policy)
  * Suggest cron and logrotate for optional features
  * Rename package 'yum-common' to 'python-yum' (Python packaging policy)
    and fix it's file permissions. Also set a more appropriate RPM group
    (Development/Languages/Python)
  * Split out rather huge lang file (rpmlint issue)
* Wed Jul 14 2010 mbarringer@suse.de
- Adding a workaround for a problem in the cpp package where it
  does not provide /lib/cpp, which xorg-x11 requires.  This patch
  manually adds a <file>/lib/cpp</file> node.
* Thu May 20 2010 mls@suse.de
- old yum versions throw an error if a package in rpmmd metadata does
  not contain a rpm:sourcerpm element. Thus we add an empty element
  if we generate output with the old "sha" checksum type.
* Thu Apr 15 2010 ro@suse.de
- move requires for python-urlgrabber to yum-common subpackage
* Mon Apr 12 2010 mbarringer@novell.com
- Porting patches over from createrepo-0.4:
  - EULA support (<license-to-confirm>)
  - SUSE changelog support
  - Adds suggests, recommends, supplements, and recommends tags
  - Disables an annoying thing where yum dumps the contents
    of a node to the terminal when the contents are not utf-8
* Wed Mar 31 2010 mbarringer@novell.com
- Removing repos.tar.bz2 from the package
- Fixing some problems with the spec file
* Thu Oct 15 2009 dmacvicar@novell.com
- update to 3.2.25. main feature yum history command
  See:
  * http://yum.baseurl.org/wiki/whatsnew/3.2.25
* Wed Oct 14 2009 dmacvicar@suse.de
- update to 3.2.24, See:
  * http://yum.baseurl.org/wiki/whatsnew/3.2.24
  * http://yum.baseurl.org/wiki/whatsnew/3.2.23
  * http://yum.baseurl.org/wiki/whatsnew/3.2.22
  * http://yum.baseurl.org/wiki/whatsnew/3.2.21
- move custom init script from patch to source file
- remove all other patches, except for null epoch workaround
* Wed Aug 12 2009 poeml@suse.de
- add kernel-default-base to exactarchlist, installonlypkgs,
  kernelpkgnames, thus making kernel updates work in 11.1
* Wed Jan  7 2009 cthiel@suse.de
- update to 3.2.20 + yum-HEAD.patch
- remove predefined repos, prepare for unsupported extra channel (SLE11)
* Tue Oct 14 2008 cthiel@suse.de
- fix repo config for 11.0 (bnc#430470)
* Wed Apr  9 2008 cthiel@suse.de
- update to version 3.2.14
  * memory footprint of yum should go down a bit thanks to some diligent
    byte-counting
  * a number of depsolving 'features' should have been fixed
  * translation updates
  * a number of unicode decode issues were fixed
* Thu Mar 20 2008 cthiel@suse.de
- update to version 3.2.13
  * 3.2.13 shows a number of significant improvements over 3.2.12 not the
    least of which is a number of depsolving bugfixes. Additionally, James
    Antill has committed some code that slightly increases memory use during
    depsolving but increases the speed of certain depsolving routines
    between 30%% and 60%%.  A significant savings for a relatively small
    memory use (8-10%%).
* Tue Mar 18 2008 cthiel@suse.de
- update to version 3.2.12
  * installed_object.verify() works much like and/or better than rpm -Va
    does now and enables the yum-verify plugin
  * a number of memory saving improvements
  * speed ups in handling of excludes
  * for both of the ia64 users it is now enabled again!
  * when depsolving we've added a number of heuristics to pick the right
    provider from a list of providers. A couple of the heuristics include:
  - see if the sourcerpm of the providing and the requiring packages is
    the same
  - see if the most characters of the package name lead match. This helps
    with cases like both totem-lirc and xmms-lirc providing the library
    for totem-debuginfo.
  * write method for the comps object in yum to write out a compliant comps
    xml file based on the imported comps files.
* Mon Feb 25 2008 crrodriguez@suse.de
- use find_lang macro
- PreReq coreutils
* Fri Feb 15 2008 cthiel@suse.de
- include /usr/share/locale
* Wed Feb 13 2008 cthiel@suse.de
- update to version 3.2.11
  - translations
  - compressed groups files are supported (in combination with a
    soon-to-be-released createrepo)
  - yum reinstall pkgname command
  - multilib_policy: Read here for an explanation, also in the man page.
    http://skvidal.wordpress.com/2008/01/30/long-wanted-feature-added-to-yum/
  - skip-broken fixes
* Fri Feb  8 2008 cthiel@suse.de
- add Requires: python-gpgme (bnc#359864)
* Thu Jan 31 2008 cthiel@suse.de
- update to version 3.2.10
  * speeding things up and trimming down the memory footprint
  * this release is substantially faster on things like: list, search and
    depsolving
* Thu Jan 24 2008 cthiel@suse.de
- improve post scripts
* Tue Jan 22 2008 cthiel@suse.de
- fix post scripts to work correctly on updates (#347280)
* Tue Dec  4 2007 cthiel@suse.de
- update to version 3.2.8
  * geode arch support
  * lots and lots of unittests
  * a fair number of transaction/depsolve bugs fixed
  * double ctrl-c to abort should work a bit more reliably
  * added an enormous amount of docstrings
  * yum search output highlights the search terms
* Thu Oct 18 2007 cthiel@suse.de
- update to version 3.2.7
  * fix transaction listing to properly display only deps as deps as opposed
    to some things which are manually done and also deps (rh#283961)
  * fix requirements moving to new packages when a package is obsoleted
  * when an obsolete is available for a package, only install most matching
    arch rather than all available arches (rh#301661)
- split of yum-updatesd package
- changed config file location from /etc/yum.conf to /etc/yum/yum.conf
* Thu Oct 11 2007 ro@suse.de
- fix build (there is room between 1030 and 1040)
* Thu Oct 11 2007 cthiel@suse.de
- added yum-3.2.6.patch to fix typo in rpmtrans.py
- added Recommends to yum-basearchonly
* Thu Oct 11 2007 cthiel@suse.de
- added yum-3.2.6-epoch_workaround.patch, to treat null epoch equal to zero
  epoch (#331818)
* Fri Oct  5 2007 cthiel@suse.de
- update to version 3.2.6
  * Mostly bug fixes in this version. A number of output changes which
    mostly just make it clearer whats going on when yum says things like
    'Nothing to do'.
  * also added a 'cost' option to repository and global configuration
    cost  relative  cost of accessing this repository. Useful for weighing
    one repo’s packages as greater/less than any other. defaults to
    1000
- changes in 3.2.5
  * We've fixed a good number of user-impacting bugs and cleaned up some
    medium-standing messes.
* Tue Sep 18 2007 cthiel@suse.de
- update default repos to include openSUSE 10.3
* Wed Aug 29 2007 cthiel@suse.de
- fix build
* Wed Aug 29 2007 cthiel@suse.de
- update to version 3.2.4
  * So, yum 3.2.3 had a few issues that needed some immediate addressing.
    Mostly the depsolving was still off by a couple and a few output
    situations blew up using the new transaction callbacks. But never fear,
    it, and an array of other items have been addressed in 3.2.4 :)
* Thu Aug 23 2007 cthiel@suse.de
- update to version 3.2.3
  * If you find a transaction aborted before it finished (or your computer
    went off or whatever) go to /var/lib/yum and compare the
    transaction-all.timestamp file with the transaction-done.timestamp file.
    The things remaining in transaction-all that aren't in transaction-done
    are what is left to do.
  * If you're confused by -e and -d as debug and error log levels you'll
    be happy to see --verbose and --quiet.
  * A bunch of plugins which exclude pkgs should be much faster now.
  * If there is something else holding the yum lock file, yum will wait
    and try again.
* Tue Aug  7 2007 cthiel@suse.de
- added yum-HEAD.patch
* Tue Aug  7 2007 cthiel@suse.de
- update to version 3.2.2
  * integrated installonlyn plugin functionality - new config option
    installonly_limit will remove old, non-running kernels from your system
    as you add more. It defaults to off, though.
  * we're downloading and saving mirrorlists locally, now, for a cached
    default. So you don't have to grab them each time if you run frequently.
  * implement an extra rpm transaction check at the end of the depsolving.
    This will help us catch invalid depsolving we might be doing. Defaults
    to on.
  * bunch of depsolving issues, multilib depsolving issues, unicode output
    issues
  * See the changelog for the complete list
- changes in version 3.2.1
  * fixes to the depsolving to get it much more correct than it was in
    3.2.0
  * catch errors from yum-updatesd more gracefully
  * series of misc fixes for encoding breakages
  * 15%% speed up of list  and list 'all' commands
  * yum search now returns results based on all search terms included and
    returns results ranked with most-matches at the top
* Mon May 21 2007 cthiel@suse.de
- update to version 3.2.0
  * latests stable release
- drop yum-install.patch, included in 3.2.0
* Thu May  3 2007 cthiel@suse.de
- added yum-3.1.7.patch to workaround bug #255914
* Thu May  3 2007 cthiel@suse.de
- update to version 3.1.7
  * We raised the minor version on yum-metadata-parser b/c we've increased
    the db version of the yum sqlite dbs to 10. yum 3.1.7 now has an
    explicit require on yum-metadata-parser 1.1.0
  * There have been a lot of changes since yum 3.1.6. The depsolver has
    changed around, we've merged optimizations from all sorts of folks and
    added in a couple of new features. As well we have hopefully fixed a
    number of bugs. :)
* Tue Apr 10 2007 cthiel@suse.de
- added yum-install.patch by Jan Matejek which replaces $(PYDIR) with
  correct value, $(PKGDIR)
* Fri Apr  6 2007 cthiel@suse.de
- update to version 3.1.6
  * 3.1.6 brings with it another round of fixes and optimizations to the
    depsolver. It also ports forward some changes from 3.0.X that were
    needed. This release should provide depsolver speed experience more
    inline with what we want.
* Tue Mar 27 2007 cthiel@suse.de
- update to version 3.1.5
  * This is a substantially less sucky yum 3.1.X release for those folks
    suffering with the depsolving rate in 3.1.4. It's still not great but
    it's a damned-sight better than it was. :)
* Fri Mar  9 2007 cthiel@suse.de
- minor typo fixes to repos.tar.bz2
* Thu Mar  8 2007 cthiel@suse.de
- added repos.tar.bz2, which includes preconfigured openSUSE channels for yum (#245899)
* Thu Mar  8 2007 cthiel@suse.de
- update to version 3.1.4
  * We've fixed a few more things in the depsolver and optimized more of the
    sqlite look ups. As well as some slowdowns in excludePackages().
* Thu Mar  1 2007 cthiel@suse.de
- update to version 3.1.3
  * more depsolver fixes on the new depsolver - it's probably working more
    accurately now, we hope. :)
  * properties - if you're using the yum module for doing any programming
    we've gotten rid of all of the need for things like doConfigSetup(),
    doRepoSetup(), doSackSetup(), etc. You can just reference the attribute
    you want and python properties will set it up for you automatically with
    the default config options. You can still call those functions, of
    course, but you only need to call them if you want to pass them
    different configuration options.
  * speed ups. We've made a lot of changes to our calls to query the sqlite
    dbs. Trimming out a lot of fat and also dumping some downright silly
    ways of doing things.
* Wed Feb 21 2007 cthiel@suse.de
- update to version 3.1.2
  * This is a development release and should not be used on systems where
    you value their continued functionality. That said, it passed all the
    release tests, for what those are worth. This is a big change from
    previous yum versions as we're doing all the dep solving inside yum. It
    doesn't download headers to do the dependency resolution.  It uses what
    information it has to do them. We were focusing on correctness with this
    release over many speedups. However, for a lot of simple cases it
    appears to be about the same as it was before, just w/o all the
    downloading during the dep resolution. We'll be adding in optimizations
    once we're more confident of the correctness of it.
* Wed Feb  7 2007 cthiel@suse.de
- update to version 3.1.1
  * download sqlite db's directly if the repository was made with createrepo
    0.4.7 or higher using the -d option.
  * should be able to handle media:// urls quasi-sanely now
  * faster package name resolution in install/update/erase commands
  * addition of a utils base class to be used by yum-utils for simpler, more
    consistent commands.
- changelog for 3.1.0
  * This is mostly 3.0.3 + some new logging patches from Terje and Tim and
    some cleanups from James.
* Mon Jan  8 2007 cthiel@suse.de
- update to version 3.0.3
  * yum/Errors.py: fixed YumError messages was not returned.  Added the
    changes made to Errors.py in HEAD, now it is working again.
  * yum/Errors.py: Fixed Traceback args is not defined
  * rpmUtils/arch.py: fixed some indentation error
  * yum/packageSack.py: try to speed up MetaSack returnObsoletes()
  * yum/Errors.py: fix error handling (rh#221470)
  * yum/packageSack.py:
  - make MetaSack returnObsoletes not take forever and a day
  - clean up the other PackageSack returnObsoletes()
  * rpmUtils/arch.py: sparc support from spot (rh#220953)
  * yum/__init__.py: thanks to terje rosten for pointing out this bug
  - fixes a dumb list of lists thing from the ListPackageSacks
  - makes groupinstall work
  * yum/__init__.py: make package checking work again
  * yum/: depsolve.py, rpmsack.py: remove the ts.close() calls in rpmsack.
    See if it helps the rpmdb locking problems. Add in some debug output in
    the depsolving so we can see how much time is spent per dep and what
    kind of dep it is
  * yum/packages.py: Add missing 'self'
  * yum/parser.py: Urlgrabber will always be used here (especially since we
    don't import urllib)
  * output.py, yum-updatesd.py, yummain.py, yum/__init__.py,
    yum/depsolve.py, yum/packageSack.py, yum/repos.py: Remove a bunch of
    unused imports
  * yum/logginglevels.py: Replace catching Exception with IOError, which
    should catch all cases
  * yum/packages.py: Undo my previous patch, since it breaks how the sql
    package overrides returnChecksums
  * yum/packages.py: Remove unneeded use of lambda in some properties
  * cli.py: whitespace fix- thanks to terje rosten
  * yum/config.py: fix up the debuglevel and errorlevel so they are set
    appropriately from the cmdline to the conf
  * yum/mdparser.py: bring back self.total here too
  * callback.py, cli.py, output.py, progress_meter.py, shell.py,
    yum-updatesd.py, bin/yum-updatesd.py, bin/yum.py, rpmUtils/miscutils.py,
    rpmUtils/updates.py, yum/comps.py, yum/depsolve.py, yum/failover.py,
    yum/mdparser.py, yum/misc.py, yum/packageSack.py, yum/packages.py,
    yum/pgpmsg.py, yum/sqlitecache.py, yum/update_md.py: Pychecker fixes
    back again, less the brokenness
  * callback.py, cli.py, output.py, progress_meter.py, shell.py,
    yum-updatesd.py, bin/yum-updatesd.py, bin/yum.py, rpmUtils/miscutils.py,
    rpmUtils/updates.py, yum/comps.py, yum/depsolve.py, yum/failover.py,
    yum/mdparser.py, yum/misc.py, yum/packageSack.py, yum/packages.py,
    yum/pgpmsg.py, yum/sqlitecache.py, yum/update_md.py: Revert previous
    pychecker fixes patch, since I broke things good and proper
  * yum/: __init__.py, packageSack.py:
  - make old obsoletes be ignored by install/update command
  - fix a variety of minor issues created by recent changes
  * callback.py, cli.py, output.py, progress_meter.py, shell.py,
    yum-updatesd.py, bin/yum-updatesd.py, bin/yum.py, rpmUtils/miscutils.py,
    rpmUtils/updates.py, yum/comps.py, yum/depsolve.py, yum/failover.py,
    yum/mdparser.py, yum/misc.py, yum/packageSack.py, yum/packages.py,
    yum/pgpmsg.py, yum/sqlitecache.py, yum/update_md.py: pychecker related
    fixes, including unused imports, and removal of use of deprecated
    methods from the string module
  * output.py: get rid of deprecation warning
  * yum/packageSack.py: Re-enable using sack.searchAll in the provides
    command. This really speeds up things, since we'll pull fewer filelists
    for packages out of the db. Looks like this broke when the metasack was
    introduced. oops. ;)
  * yum/yumRepo.py: Remove unused code for manipulating the
    failure_obj during __get
  * yum/__init__.py:
  - fix a deprecation warning
  - give an idea of where gpg keys come from on the import; add a new
    callback method that's more extensible
  * cli.py, shell.py, yumcommands.py, yummain.py: Implement the ShellCommand
    code
  * yum/plugins.py: Close the file descriptor used by imp in case an
    exception is thrown.
  * yum-updatesd.py, yummain.py, yum/__init__.py: Provide a default file
    name for doLock and doUnlock
  * yum/storagefactory.py: Only catch ImportError in storagefactory
  * yum/Errors.py: apply patch for bug #670 - thanks to Joe Shaw
  * docs/yum.conf.5, yum/__init__.py, yum/config.py: allow setting the type
    of packages that will be installed by default on a 'groupinstall'
    command.
  * cli.py: fix format error (rh#212850)
  * yum/yumRepo.py: fix progress_obj typo - back to 3.0.X
  * yum/sqlitesack.py: check in changelog changes to 3.0.X
  * yum/misc.py: make sure we're comparing versions - thanks to pjones
  * yum-updatesd.py: init plugins, fix log config (jbowes)
  * etc/yum-updatesd.init: fix tyop (rh#214298)
  * etc/yum-updatesd.conf: add a comment and the dbus_listener option
    (rh#214242)
  * yum-updatesd.py: fix excludes (rh#213622, rh#212494) and
    auto-update (rh#212507)
  * cli.py: print out version before plugins are loaded (rh#212292)
- removed old patches
- added yum-python25.patch to drop python-sqlite requirement (use sqlite3
  instead)
- removed obsolete requires to libxml2-python
* Wed Nov  1 2006 cthiel@suse.de
- update to version 3.0.1
  * Makefile, docs/Makefile: Add docs target to Makefile for epydoc
    generation
  * yum/misc.py: file can be a unicode string
  * yum/yumRepo.py:
    actually return the checksum value
  * yum/: comps.py, config.py, logginglevels.py, misc.py,
    packages.py, repos.py, sqlitesack.py, storagefactory.py,
    yumRepo.py:
  - lots of pychecker fixes
  - remove duplicate code for checksumming
  - clean up some potential bugs
  * yum-updatesd.py, yum/parser.py:
  - remove IncludingConfigParser,IncludedConfigParser
  - make yum-updatesd.py use ConfigPreProcessor for include= config files
  * yum/packages.py: bring back equality of package objects
  * yum/depsolve.py: EVR comparison
  * yum/packages.py: Fix comparisons using PackageEVR
  * cli.py, yum/packageSack.py, yum/packages.py: fix so that
    foo-1.1-1.i386 != foo-1.1-1.x86_64.  at the same time, move
    comparison to be of an EVR object and adjust callers accordingly.
    patch for EVR comparison
  * yum/logginglevels.py: close the syslog handler if it fails to get
    +set up (rh#208773)
  * yum/rpmsack.py: fix typo
  * yum/rpmsack.py:
  - speed up searchNevra() by building a pkgtup->headerindex dict -
    make the header_from_index() method work by deleting match iterator
  each time explicitly.
  * yum/__init__.py: raise the right error... this ended up
    manifesting itself by raising the last error (which had been passed
    on) instead of the intended and an entirely non-obvious traceback.
    moral of the story: always raise a specific exception
  * yum/parser.py: fix var expansion
  * yum/yumRepo.py: fix handling of base path
  * yum-updatesd.py: definition moved
* Thu Oct 26 2006 cthiel@suse.de
- added patches by Jeremy Katz <katzj@redhat.com>
  * yum-python25-etree.patch, only require python-elementtree old dists
  * yum-error-vals.patch, fixes #214119
* Thu Oct  5 2006 cthiel@suse.de
- update to version 3.0
  * yum/depsolve.py: messing around with a few tests to figure out where it
    is slow.
  * shell.py, yum/depsolve.py: make the fix for pekka's bug more correct
  * shell.py: fix for the traceback Pekka reported - makes sure that our ts
    is reopened/intialized when the user decides to not run the transaction
    from the shell.
  * yum/plugins.py: replaced IncludingConfigParser with
    ConfigPreProcessor/ConfigParser in plugins, so i works like the rest of
    yum.
  * yum/packages.py: * add a remote_url property for packages to get the
    remote location as a string that can be printed * get rid of some
    explicit uses of relativepath
  * yum/config.py: Copy the default value in case it is mutable and
    different config instances end up manipulating the same default value.
  * yum/plugins.py: fix for this error : AttributeError: 'module' object has
    no attribute 'IncludingConfigParser' When running latest yum-cvs with
    plugins.
  * yum/: __init__.py, config.py, parser.py: make the include= and yum -c
    http://path/to/file behave like I thought they should.
  * yum/config.py: put accidentally removed line back
  * yum/: packages.py, repos.py: cleaned up Repository.setkeys as discussed
    on yum-devel
  * yum/config.py: Removed on the fly write-back support from the config
    classes. Added BaseConfig.write() instead. This is simpler and should
    use less memory. No-one was using the write support anyway.
* Sun Oct  1 2006 cthiel@suse.de
- update to version 2.9.8
  * yum/rpmsack.py: minor fix to deprecated returnTupleByKeyword method in
    rpmsack.
  * cli.py: make sure we're not accidentally trying to install an old
    version
  * yum/repos.py: make excludes (and who knows how many other things) work
    again.  This, however, may not be the correct fix - willing to roll it
    back out
  * yum/packageSack.py: make sure we're only returning the newest from the
    metasack
  * yum/__init__.py: if we have a local copy of the package that checksums
    fine, use it instead of trying to do a range request from the end of the
    file
  * yum-updatesd.py: define a checkFailed signal so that watchers can notify
    users about failures to check for updates
  * yum/config.py: Commited James Bowes' inheritance fix and simplify the
    logic.
  * cli.py, shell.py, yumcommands.py, yum/plugins.py: Committed Bastiaan
    Bakker's command extension patch.
  * yum-updatesd.py: some error logging; avoid leaving a stale lock file
  * yum/packages.py: lazily populate prco to speed up rpmsack initialization
    when it's not needed
  * yum/packages.py: fix dep installs for locales like turkish where
    string.lower("I") != "i"
  * yum/logginglevels.py: if we can't connect to a syslog, don't die
  * yum/rpmsack.py: Removed unused excludes attribute and updated comments
  * yum/: __init__.py, config.py, yumRepo.py: As discussed privately with
    Paul Nasrat, merged YumRepository and RepoConf to help allow config
    dumping.
  * yum-updatesd.py: * actually time out after a few tries * catch another
    place we could potentially not unlock the pid file
  * yum/: packages.py, sqlitesack.py: swap arguments on __init__ for a few
    Package types so that we have consistency
  * yum/__init__.py: clean up some duplicate code to take advantage of the
    fact that the rpmdb is now a package sack
  * yum/yumRepo.py: we need to redo setupGrab() after changing callbacks so
    that our grabber has the right info.  this makes it so that we get
    progress feedback when downloading in pirut again
  * cli.py, yum/__init__.py: fix whatprovides based on a patch from Tim
    Lauridsen
  * yum/rpmsack.py: makePackageObject -> _makePackageObject
  * yum/__init__.py: Fixed the disk space check; it was failing because
    po.size can be a string.  Make the disk space check more readable by
    using the statvfs attributes.
  * yum/__init__.py: Prevent a KeyError that was occur during the disk space
    check because errors wasn't always initialised correctly. Added
    adderror() to avoid initialisation problems like this and minimise
    clutter.
  * yum/: __init__.py, packages.py: partial check in just to get it off my
    laptop: 1. do check for space in cache dir for downloading packages 2.
    start changing around the way packages are checked
  * yum/: __init__.py, packages.py: get rid of silly code in verifyPkg()
  * yum/rpmsack.py: as I read through the changes: - clean up one docstring
  - make some of the list constructions using _search look the same
  * yum/rpmsack.py: make getNameArchPkgList() and getNamePkgList()
    consistent - if our pkglist is length zero then they would have traced
    back.
  * yum/: __init__.py, misc.py, packages.py:
  - move refineSearchPattern into misc from YumBase
  - clean up some pychecker errors
  * yum/rpmsack.py: Big cleanup of RPMDBPackageSack. Indexes are no longer
    built (buildIndexes).  This significantly reducing Yum's initialisation
    time and reduces memory footprint. Despite the lack of indexes almost
    all operations are faster.
  * cli.py, output.py, yum/__init__.py, yum/misc.py, yum/packages.py:
  - fix up findDeps interface
  - it now takes a list of package objects
  - clean up a deprecation in deplistoutput
  - remove RpmBase._prcoTuple2Printable() since it was no longer needed
    and only introduced in this devel series.
  * cli.py: more obvious error message for group not existing
  * cli.py: remove a bunch of unused imports
  * cli.py: use TYPE_INTERACTIVE instead of the deprecated TYPE_INTERFACE
  * rpmUtils/miscutils.py: make epoch output quasi-consistent for
    comparisons
  * yum/depsolve.py: add some debug output to depsolving
- require rpm >= 4.4
* Wed Sep  6 2006 maw@suse.de
- Update to version 2.9.6, required by rum
- Remove yum-${version}-misc.patch and yum-syslog.patch, which are
  now upstream.
* Mon Aug  7 2006 cthiel@suse.de
- fix build
* Sat Aug  5 2006 cthiel@suse.de
- update to version 2.9.3
  * new dev cycle
- require yum-metadata-parser
- added yum-2.9.3-misc.patch and yum-syslog.patch from Fedora
- updated yum.conf
- don't package yum updatesd for now
* Thu May 25 2006 cthiel@suse.de
- update to version 2.6.1
  * includes countless bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Dec 18 2005 cthiel@suse.de
- update to version 2.4.2
* Wed Nov 30 2005 cthiel@suse.de
- update to version 2.4.1
* Mon Oct 31 2005 dmueller@suse.de
- build as nonroot
* Thu Sep 15 2005 cthiel@suse.de
- specfile cleanup
* Sat Aug 27 2005 cthiel@suse.de
- adapt yum's defaults to SUSE Linux
* Tue Aug 16 2005 cthiel@suse.de
- update to version 2.4.0
* Sun Aug 14 2005 cthiel@suse.de
- initial package (version 2.3.4)
